package proto.flight.service;

import javax.xml.ws.WebServiceException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import framework.exception.ExceptionParser;
import framework.exception.RemoteServiceException;
import framework.ws.*;

import proto.flight.exception.FlightDomainException;
import proto.flight.view.ReservationVoucher;
import proto.flight.wsdl.*;
import proto.flight.ws.client.*;


public class CreateFlightReservationService extends FlightBaseService<ReservationVoucher> {

    /** logging */
    private Log log = LogFactory.getLog(CreateFlightReservationService.class);

    /* service members */
    private String origin;
    private String destination;
    private String id;
    private String name;

    /* constructor */
    public CreateFlightReservationService(String origin, String destination, String id, String name) {
        this.origin = origin;
        this.destination = destination;
        this.id = id;
        this.name = name;
    }

    @Override
    protected ReservationVoucher action() throws FlightDomainException {
        try {
            // create Web Service stub
            FlightPortType port = FlightStubFactory.getInstance().getPortUsingConfig();

            // invoke remote service
            Passenger passenger = new Passenger();
            passenger.setId(this.id);
            passenger.setName(this.name);

            ReservationVoucher voucher = port.createReservation(this.origin, this.destination, passenger);

            log.debug("Reservation code: " + voucher.getReservationCode());
            log.debug("Reservation flight number: " + voucher.getFlightNumber());

            return voucher;
        } catch (FlightFault_Exception e) {
            // remote domain exception
            log.error(e);
            FlightDomainException ex = ExceptionParser.parse(e.getFaultInfo().getFaultType(), e.getMessage());
            throw ex;
        } catch (ServiceError_Exception e) {
            // remote service error
            log.error(e);
            throw new RemoteServiceException(e);
        } catch (StubFactoryException e) {
            // stub creation error
            log.error(e);
            throw new RemoteServiceException(e);
        } catch (WebServiceException e) {
            // communication error (wrong address, connection closed, ...)
            log.error(e);
            throw new RemoteServiceException(e);
        }

    }

}
